#! /bin/sh
# @(#)updatemidas.sh	1.1 (ESO-IPG) 07/12/91 14:16:05
# .COPYRIGHT: Copyright (c) 1988 European Southern Observatory,
#                                         all rights reserved
# .TYPE           command
# .NAME           updatemidas.sh
# .LANGUAGE       shell script
# .ENVIRONMENT    Unix Systems. Executable under SHELL and C-SHELL
# .COMMENTS       Updating procedure of the MIDAS system. 
#                 The MIDAS system is installed with the "installmidas"
#                 command and is executed just once. Henceforth, the
#                 system will be updated for any modification with the
#                 "updatemidas" command.
#                 
#                 Usage: updatemidas [options]
#                 
#                    options: are options for the "make" command. This option
#                             will be exported to all the directories of the
#                             update procedure.
#			      Multiple definitions for keywords must be:
#				e.g.	CFLAGS=\"-O -g -I/usr/include\"
#			      to avoid quotes to be interpreted by the shell.
#
#                 The command executes the following steps:
#
#                    - First of all, it checks if the $MIDASHOME and $MIDVERS
#                      shell parameter are defined. If not.. Bye.
#                        
#                    - $MIDASHOME/local/make_options is read if exists. It
#                      contains local options for "make" commands.a
#                        
#                    - All the directories involved are
#                      read from $MID_INSTALL/midas.cnf. To add a
#                      new directory to the installation edit that file.
#                      
#                    - Running "make options" in all the directories updating
#                      only those files involved in the update.
#
#                    - Check of executables and library files.
#
# .AUTHOR         Carlos Guirao
# .VERSION 1.1    13-May-1988:		Implementation
# .VERSION 2.0    23-Jun-1988:		Adding local files
# .VERSION 2.1    03-Jan-1989:		Multiple options for keywords in
#					arguments and make_options file
# .VERSION 2.2    910219:		Removing SYSTEM name as argument

# 
# First of all, check if $MIDASHOME or $MIDVERS are defined
#
if [ $MIDASHOME ]
then
	continue
else
	echo "\$MIDASHOME is undefined"
	echo "Please, set \$MIDASHOME and \$MIDVERS before INSTALLMIDAS"
	exit
fi
if [ $MIDVERS ]
then
	continue
else
	echo "\$MIDVERS is undefined"
	echo "Please, set \$MIDASHOME and \$MIDVERS before INSTALLMIDAS"
	exit
fi

MID_INSTALL=$MIDASHOME/$MIDVERS/install/unix

#
# Local options for makes commands will be read if they exits in the
# make_options file, from the local directory.
# Other options can be set in the command line of this script as the
# second parameter: $2. These option will replace those local option with 
# the same name
#
if [ -r $MIDASHOME/local/make_options ]
then
	echo ""
	echo "Reading your $MIDASHOME/local/make_options file...:"
	LOCAL_OPT=`cat $MIDASHOME/local/make_options | awk -F# '{print $1}'`
	echo "$LOCAL_OPT"
	echo ""
fi

echo "*********************************************************************"
echo "******************** MIDAS UPDATING PROCEDURE ***********************"
echo "*********************************************************************"
echo "******************** MIDASHOME: $MIDASHOME  VERSION: $MIDVERS"
echo "******************** DATE:  `date`"
echo "******************** COMMAND: $0 $*"

for i in `cat $MID_INSTALL/midas.cnf`
do
	# if line in comments
	comment=`echo $i | sed 's/^\(.\).*/\1/'`
	# echo "comment=$comment"
	if [ $comment = "#" ]
	then
		continue
	fi

	dir=`eval echo $i`
	cd $dir
	echo ""
	echo "**********************************************"
	echo "****** UPDATING IN $dir"
	echo "**********************************************"
	echo "****** DATE:  `date`"
	eval make "$@" $LOCAL_OPT
done

echo ""
echo "*********************************************************************"
echo "************************ END UPDATING PROCEDURE *********************"
echo "*********************************************************************"
echo "********** END DATE:  `date`"
